@@ -310,6 +310,8 @@ def database_explorer(name):
         health_check_url=url_for('database_health_check', database=name),
         backup_url = url_for('backup_database', database=name),
         delete_url = url_for('delete_database', database=name),
+        location_facet_url = url_for('facet', database=name, facet="location"),
+        unit_facet_url = url_for('facet', database=name, facet="unit"),
     )
 
 
@@ -416,6 +418,50 @@ def json_editor(database, code):
     return render_template("jsoneditor.html", jsondata=JsonWrapper.dumps(data))
 
 
+###################
+### Facet views ###
+###################
+
+
+@bw2webapp.route("/database/<database>/facet/<facet>")
+def facet(database, facet):
+    def reformat(key, ds):
+        return {
+            'name': ds.get('name', "Unknown"),
+            'categories': ",".join(ds.get('categories', [])),
+            'location': ds.get('location', ''),
+            'unit': ds.get('unit', ''),
+            'url': url_for('activity_dataset-canonical', database=key[0], code=key[1]),
+        }
+
+    if database not in databases:
+        return abort(404)
+    data = Database(database).load()
+    facets = {}
+    for key, ds in data.items():
+        try:
+            facets.setdefault(ds[facet], []).append(reformat(key, ds))
+        except KeyError:
+            abort(404)
+    facet_data = [
+        (key + " (%s)" % len(facets[key]), "facet%s" % index, JsonWrapper.dumps(facets[key]))
+        for index, key in enumerate(sorted(facets.keys()))
+    ]
+    tree_data = [{'id': o[1], 'text': o[0]} for o in facet_data]
+    tree_data[0]['state'] = {'selected': True}
+    kwargs = {
+        "tree_data": JsonWrapper.dumps(tree_data),
+        "data": facet_data,
+        "db": database,
+        "facet": facet
+    }
+    return render_template("facets.html", **kwargs)
+
+####################
+### Health check ###
+####################
+
+
 @bw2webapp.route("/database/<database>/health-check")
 def database_health_check(database):
     if database not in databases:
@@ -538,28 +584,33 @@ def report(uuid):
 @bw2webapp.route("/method/<abbreviation>")
 def method_explorer(abbreviation):
     method = [key for key, value in methods.iteritems()
-        if value['abbreviation'] == abbreviation]
+        if value[u'abbreviation'] == abbreviation]
     if not len(method) == 1:
         abort(404)
     method = method[0]
     meta = methods[method]
     json_data = []
-    for key, value, geo in Method(method).load():
+    for values in Method(method).load():
+        if len(values) >= 3:
+            key, value, geo = values[:3]
+        else:
+            key, value = values[:2]
+            geo = config.global_location
         flow = Database(key[0]).load()[key]
         json_data.append({
-            'name': flow.get('name', "Unknown"),
-            'unit': flow.get('unit', ''),
-            'categories': ",".join(flow.get('categories', [])),
-            'cf': value['amount'] if isinstance(value, dict) else value,
-            'location': geo,
-            'url': url_for('activity_dataset-canonical', database=key[0], code=key[1])
+            u'name': flow.get(u'name', u"Unknown"),
+            u'unit': flow.get(u'unit', ''),
+            u'categories': ",".join(flow.get(u'categories', [])),
+            u'cf': value[u'amount'] if isinstance(value, dict) else value,
+            u'location': geo,
+            u'url': url_for('activity_dataset-canonical', database=key[0], code=key[1])
         })
-    json_data.sort(key=lambda x: x['name'])
+    json_data.sort(key=lambda x: x[u'name'])
     return render_template(
         "method.html",
         name=method,
-        unit=meta['unit'],
-        description=meta['description'],
+        unit=meta.get(u'unit', u''),
+        description=meta.get(u'description', u''),
         data=JsonWrapper.dumps(json_data)
     )
 
